@@ -38,7 +38,6 @@ class AWSTransformer(Transformer):
         """Initialize associate provider and transformer display name."""
         self.dsp_name = "AWS"
         await self._provider.init(
-            ami_ids=self.config["images"].values(),
             ssh_key=self.config["keypair"],
             instance_tags=self.config["instance_tags"],
             strategy=self.config.get("strategy", STRATEGY_ABORT),
@@ -60,15 +59,18 @@ class AWSTransformer(Transformer):
 
     def create_host_requirement(self, host):
         """Create single input for AWS provisioner."""
-        required_image = host.get("image") or self._get_image(host["os"])
+        del_vol = self._find_value(
+            host, "delete_volume_on_termination", None, None, True
+        )
         req = {
             "name": host["name"],
             "os": host["os"],
             "group": host["group"],
             "flavor": self._get_flavor(host),
-            "image": required_image,
-            "meta_image": "image" in host,
+            "image": self._get_image(host),
             "security_group_ids": self._get_security_groups(),
+            "spot": self._find_value(host, "spot", None, None),
+            "delete_volume_on_termination": del_vol,
         }
         if self.config.get("subnet_id"):
             req["subnet_id"] = self.config.get("subnet_id")
